==> bigloo2.0a.tar.gz: bigloo2.0a/comptime/Foreign/calias.scm <==
;*---------------------------------------------------------------------*/
;*   A pratical implementation for the Scheme programming language     */
;*                                                                     */
;*                                    ,--^,                            */
;*                              _ ___/ /|/                             */
;*                          ,;'( )__, ) '                              */
;*                         ;;  //   L__.                               */
;*                         '   \\   /  '                               */
;*                              ^   ^                                  */
;*                                                                     */
;*   Copyright (c) 1992-1999 Manuel Serrano                            */
;*                                                                     */
;*     Bug descriptions, use reports, comments or suggestions are      */
;*     welcome. Send them to                                           */
;*       bigloo-request@kaolin.unice.fr                                */
;*       http://kaolin.unice.fr/bigloo                                 */
;*                                                                     */
;*   This program is free software; you can redistribute it            */
;*   and/or modify it under the terms of the GNU General Public        */
;*   License as published by the Free Software Foundation; either      */
;*   version 2 of the License, or (at your option) any later version.  */
;*                                                                     */
;*   This program is distributed in the hope that it will be useful,   */
;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
;*   GNU General Public License for more details.                      */
;*                                                                     */
;*   You should have received a copy of the GNU General Public         */
;*   License along with this program; if not, write to the Free        */
;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
;*   MA 02111-1307, USA.                                               */
;*---------------------------------------------------------------------*/
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime1.9/Foreign/calias.scm       */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Thu Jun  6 12:25:42 1996                          */
;*    Last change :  Thu Sep  5 16:39:36 1996 (serrano)                */
;*    -------------------------------------------------------------    */
;*    The C alias accessors creations.                                 */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module foreign_calias
   (include "Tools/trace.sch")
   (import  type_tools
	    type_type
	    tools_shape
	    foreign_ctype
	    foreign_access))
   
;*---------------------------------------------------------------------*/
;*    make-ctype-accesses! ::calias ...                                */
;*---------------------------------------------------------------------*/
(define-method (make-ctype-accesses! what::calias who::type)
   (trace (expand 3)
	  "make-ctype-accesses(calias): " (shape what) " " (shape who)
	  #\Newline)
   (make-ctype-accesses! (type-alias what) who))

==> bigloo3.1a.tar.gz: bigloo3.1a/comptime/Foreign/calias.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime/Foreign/calias.scm          */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Thu Jun  6 12:25:42 1996                          */
;*    Last change :  Mon May 15 07:48:06 2000 (serrano)                */
;*    Copyright   :  1996-2000 Manuel Serrano, see LICENSE file        */
;*    -------------------------------------------------------------    */
;*    The C alias accessors creations.                                 */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module foreign_calias
   (include "Tools/trace.sch")
   (import  type_tools
	    type_type
	    tools_shape
	    foreign_ctype
	    foreign_access))
   
;*---------------------------------------------------------------------*/
;*    make-ctype-accesses! ::calias ...                                */
;*---------------------------------------------------------------------*/
(define-method (make-ctype-accesses! what::calias who::type loc)
   (trace (expand 3)
	  "make-ctype-accesses(calias): " (shape what) " " (shape who)
	  #\Newline)
   (make-ctype-accesses! (type-alias what) who loc))
